==> qt5-tools-debuginfo-5.9.2-1.tar.xz: usr/src/debug/qt5-tools-5.9.2-1/examples/assistant/remotecontrol/.rcc/qrc_remotecontrol.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.9.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/qt5-tools/qt5-tools-5.9.2-1.x86_64/src/qttools-opensource-src-5.9.2/examples/assistant/remotecontrol/enter.png
  0x0,0x0,0x1,0x3b,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x8,0x6,0x0,0x0,0x0,0x1f,0xf3,0xff,0x61,
  0x0,0x0,0x0,0x9,0x70,0x48,0x59,0x73,0x0,0x0,0xb,0x13,0x0,0x0,0xb,0x13,
  0x1,0x0,0x9a,0x9c,0x18,0x0,0x0,0x0,0x7,0x74,0x49,0x4d,0x45,0x7,0xd7,0x6,
  0x16,0xc,0x11,0x13,0xe7,0xa0,0xe0,0x7e,0x0,0x0,0x0,0x1d,0x74,0x45,0x58,0x74,
  0x43,0x6f,0x6d,0x6d,0x65,0x6e,0x74,0x0,0x43,0x72,0x65,0x61,0x74,0x65,0x64,0x20,
  0x77,0x69,0x74,0x68,0x20,0x54,0x68,0x65,0x20,0x47,0x49,0x4d,0x50,0xef,0x64,0x25,
  0x6e,0x0,0x0,0x0,0x6,0x62,0x4b,0x47,0x44,0x0,0xff,0x0,0xff,0x0,0xff,0xa0,
  0xbd,0xa7,0x93,0x0,0x0,0x0,0x9f,0x49,0x44,0x41,0x54,0x38,0xcb,0x63,0x60,0x20,
  0x1e,0x30,0x2,0x31,0x33,0x10,0x9b,0x0,0x31,0x1f,0x3,0x19,0x0,0xa4,0x79,0x2e,
  0x10,0xcf,0x3,0x62,0x25,0x72,0xc,0x0,0xd9,0xfa,0x1f,0x8a,0xf5,0xc9,0x31,0x40,
  0x16,0x88,0xff,0x41,0xd,0xf0,0x23,0xc7,0x0,0x76,0x20,0xfe,0xb,0x35,0x20,0x90,
  0x81,0x4c,0x0,0xf3,0x42,0x28,0xdd,0xc,0x90,0xa1,0xc4,0x0,0x90,0xa2,0x75,0xd0,
  0xf8,0x27,0xd9,0x80,0x60,0x20,0xfe,0x1,0xc4,0x9b,0xc9,0x71,0x41,0x18,0x34,0xba,
  0x40,0xf8,0x12,0x10,0x97,0x1,0x71,0x25,0x10,0x97,0x13,0x63,0x40,0x1c,0x10,0xff,
  0x46,0x52,0x88,0xb,0x7,0xa3,0xa7,0x71,0x18,0x50,0x5,0xe2,0x87,0xd0,0xf8,0x6,
  0x19,0xf4,0x7,0x8d,0x6,0xe1,0x8b,0x40,0x2c,0x81,0x6c,0x0,0x13,0x96,0x90,0x7f,
  0xc,0xb5,0x69,0x15,0xb9,0xf1,0xd,0x33,0x84,0x90,0x1,0x8c,0x30,0x82,0x11,0x87,
  0x21,0x7d,0x84,0x6c,0x2,0x0,0xee,0x1c,0x35,0xad,0x6e,0x7d,0xe3,0x4e,0x0,0x0,
  0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // remotecontrol
  0x0,0xd,
  0xb,0xed,0x6d,0xdc,
  0x0,0x72,
  0x0,0x65,0x0,0x6d,0x0,0x6f,0x0,0x74,0x0,0x65,0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x74,0x0,0x72,0x0,0x6f,0x0,0x6c,
    // enter.png
  0x0,0x9,
  0xa,0xc5,0x8f,0xe7,
  0x0,0x65,
  0x0,0x6e,0x0,0x74,0x0,0x65,0x0,0x72,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/remotecontrol
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/remotecontrol/enter.png
  0x0,0x0,0x0,0x20,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x5e,0xc7,0xb5,0xc8,0xc8,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_remotecontrol)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_remotecontrol)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_remotecontrol)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_remotecontrol)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_remotecontrol)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_remotecontrol)(); }
   } dummy;
}

==> qt5-tools-debuginfo-5.9.3-1.tar.xz: usr/src/debug/qt5-tools-5.9.3-1/examples/assistant/remotecontrol/.rcc/qrc_remotecontrol.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.9.3
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/qt5-tools/qt5-tools-5.9.3-1.i686/src/qttools-opensource-src-5.9.3/examples/assistant/remotecontrol/enter.png
  0x0,0x0,0x1,0x3b,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x8,0x6,0x0,0x0,0x0,0x1f,0xf3,0xff,0x61,
  0x0,0x0,0x0,0x9,0x70,0x48,0x59,0x73,0x0,0x0,0xb,0x13,0x0,0x0,0xb,0x13,
  0x1,0x0,0x9a,0x9c,0x18,0x0,0x0,0x0,0x7,0x74,0x49,0x4d,0x45,0x7,0xd7,0x6,
  0x16,0xc,0x11,0x13,0xe7,0xa0,0xe0,0x7e,0x0,0x0,0x0,0x1d,0x74,0x45,0x58,0x74,
  0x43,0x6f,0x6d,0x6d,0x65,0x6e,0x74,0x0,0x43,0x72,0x65,0x61,0x74,0x65,0x64,0x20,
  0x77,0x69,0x74,0x68,0x20,0x54,0x68,0x65,0x20,0x47,0x49,0x4d,0x50,0xef,0x64,0x25,
  0x6e,0x0,0x0,0x0,0x6,0x62,0x4b,0x47,0x44,0x0,0xff,0x0,0xff,0x0,0xff,0xa0,
  0xbd,0xa7,0x93,0x0,0x0,0x0,0x9f,0x49,0x44,0x41,0x54,0x38,0xcb,0x63,0x60,0x20,
  0x1e,0x30,0x2,0x31,0x33,0x10,0x9b,0x0,0x31,0x1f,0x3,0x19,0x0,0xa4,0x79,0x2e,
  0x10,0xcf,0x3,0x62,0x25,0x72,0xc,0x0,0xd9,0xfa,0x1f,0x8a,0xf5,0xc9,0x31,0x40,
  0x16,0x88,0xff,0x41,0xd,0xf0,0x23,0xc7,0x0,0x76,0x20,0xfe,0xb,0x35,0x20,0x90,
  0x81,0x4c,0x0,0xf3,0x42,0x28,0xdd,0xc,0x90,0xa1,0xc4,0x0,0x90,0xa2,0x75,0xd0,
  0xf8,0x27,0xd9,0x80,0x60,0x20,0xfe,0x1,0xc4,0x9b,0xc9,0x71,0x41,0x18,0x34,0xba,
  0x40,0xf8,0x12,0x10,0x97,0x1,0x71,0x25,0x10,0x97,0x13,0x63,0x40,0x1c,0x10,0xff,
  0x46,0x52,0x88,0xb,0x7,0xa3,0xa7,0x71,0x18,0x50,0x5,0xe2,0x87,0xd0,0xf8,0x6,
  0x19,0xf4,0x7,0x8d,0x6,0xe1,0x8b,0x40,0x2c,0x81,0x6c,0x0,0x13,0x96,0x90,0x7f,
  0xc,0xb5,0x69,0x15,0xb9,0xf1,0xd,0x33,0x84,0x90,0x1,0x8c,0x30,0x82,0x11,0x87,
  0x21,0x7d,0x84,0x6c,0x2,0x0,0xee,0x1c,0x35,0xad,0x6e,0x7d,0xe3,0x4e,0x0,0x0,
  0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // remotecontrol
  0x0,0xd,
  0xb,0xed,0x6d,0xdc,
  0x0,0x72,
  0x0,0x65,0x0,0x6d,0x0,0x6f,0x0,0x74,0x0,0x65,0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x74,0x0,0x72,0x0,0x6f,0x0,0x6c,
    // enter.png
  0x0,0x9,
  0xa,0xc5,0x8f,0xe7,
  0x0,0x65,
  0x0,0x6e,0x0,0x74,0x0,0x65,0x0,0x72,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/remotecontrol
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/remotecontrol/enter.png
  0x0,0x0,0x0,0x20,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x5f,0x9a,0xa1,0x2d,0x18,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_remotecontrol)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_remotecontrol)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_remotecontrol)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_remotecontrol)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_remotecontrol)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_remotecontrol)(); }
   } dummy;
}
